==> eventcontrol-1.0.1.tgz: package/README.md <==
# eventcontrol

An event controller that allows you to add callbacks to a list and have them fire when the event is dispatched.

Install it with ```npm i eventcontrol```

https://www.npmjs.com/package/eventcontrol

## Usage

### NodeJS example

```javascript
//in one class file
const eventcontrol = require("eventcontrol");
class Example {
  exampleCallback(optional, arg1, arg2) {
    console.log("exampleCallback fired!", this, arg1, arg2);
  }
  someOtherFunction() {
    //hook up that callback to this event string 'EVENT_FIRED'
    eventcontrol.add("EVENT_FIRED", someCallback, this, optional);
  }
}
```

```javascript
//in another class file
const eventcontrol = require("eventcontrol");
class SomeOtherClass {
  doingSomething() {
    eventcontrol.emit("EVENT_FIRED", "arg1", "arg2");
  }
}
```

Using it like this should show you what options you have with regards to passing arguments (which are all optional).
Note the order of the arguments received in the exampleCallback.

I've also provided an example from a react project below. This has a nice use case when you need an event to fire
without actually changing any props and you don't want to add too much code to hook up something like redux.

### ReactJS example
```javascript
import eventcontrol from "eventcontrol";
import { eventTypes } from "../events";

class SomeComponent extends Component {
  someEventCallback(arg1, arg2) {
    console.log("someEventCallback fired!", this, arg1, arg2);
  }
  componentDidMount() {
    eventcontrol.add(eventTypes.SOME_EVENT_NAME, this.someEventCallback, this);
  }
  componentWillUnmount() {
    eventcontrol.remove(eventTypes.SOME_EVENT_NAME, this.someEventCallback);
  }
}
```

```javascript
import eventcontrol from "eventcontrol";
import { eventTypes } from "../events";

class OtherComponent extends Component {
  someFunction() {
    eventcontrol.emit(eventTypes.SOME_EVENT_NAME, 123, "hello world");
  }
}
```

==> eventcontrol-1.1.2.tgz: package/README.md <==
# eventcontrol

An event controller that allows you to add callbacks to a list and have them fire when the event is dispatched.

[![npm version](https://img.shields.io/npm/v/eventcontrol.svg?color=%232c8ebb&style=flat-square)](https://www.npmjs.com/package/eventcontrol)
![npm bundle size](https://img.shields.io/bundlephobia/minzip/eventcontrol.svg?color=rgb%28113%2C%20138%2C%20240%29&label=gzipped&style=flat-square)
[![MIT license](https://img.shields.io/npm/l/eventcontrol.svg?color=%233DA639&style=flat-square)](http://opensource.org/licenses/MIT)

## Usage

Add an event listener by calling

```javascript
eventcontrol.add("EVENT_NAME", functionToCall);
```

functionToCall will fire when eventcontrol is emitted

```javascript
eventcontrol.emit("EVENT_NAME");
```

You can add extra arguments, or extra functions to listen to the same event. See examples below.

### NodeJS example

```javascript
//in one class file
const eventcontrol = require("eventcontrol");
class Example {
  exampleCallback(optional, arg1, arg2) {
    console.log("exampleCallback fired!", this, arg1, arg2);
  }
  someOtherFunction() {
    //hook up that callback to this event string 'EVENT_FIRED'
    eventcontrol.add("EVENT_FIRED", this.exampleCallback, this, optional);
  }
}
```

```javascript
//in another class file
const eventcontrol = require("eventcontrol");
class SomeOtherClass {
  doingSomething() {
    eventcontrol.emit("EVENT_FIRED", "arg1", "arg2");
  }
}
```

Using it like this should show you what options you have with regards to passing arguments (which are all optional).
Note the order of the arguments received in the exampleCallback.

I've also provided an example from a react project below. This has a nice use case when you need an event to fire
without actually changing any props and you don't want to add too much code to hook up something like redux.

### ReactJS example

```javascript
import eventcontrol from "eventcontrol";
import { eventTypes } from "../events";

class SomeComponent extends Component {
  someEventCallback(arg1, arg2) {
    console.log("someEventCallback fired!", this, arg1, arg2);
  }
  componentDidMount() {
    eventcontrol.add(eventTypes.SOME_EVENT_NAME, this.someEventCallback, this);
  }
  componentWillUnmount() {
    eventcontrol.remove(eventTypes.SOME_EVENT_NAME, this.someEventCallback);
  }
}
```

```javascript
import eventcontrol from "eventcontrol";
import { eventTypes } from "../events";

class OtherComponent extends Component {
  someFunction() {
    eventcontrol.emit(eventTypes.SOME_EVENT_NAME, 123, "hello world");
  }
}
```
